Skip to contents

A friendly greeting for a person we know by name

Usage

xhello(.name)

Arguments

.name

the name of the person we want to greet

Value

string comprising "Greeting + name provided

Examples

xhello("Stranger")
#> [1] "Greetings Stranger"